# CHANGE LOG

## 2021-05-12

- Release Visko package

## 2021-05-11

- Visko only depends on Django < 2.0 and coolisf 0.2.3 on PyPI
- Visko 0.2.3 release candidate 1 is ready

## 2021-05-03

- Wrap up PhD code, prepare for post-PhD release 

## 2016-06-10

- Change `Representation` table to `Interpretation` (I have no idea why I call it `Representation` in the first place!)


## 2016-05-31

- Restructure project
- Flatten database structure
- Migrate to Django 1.9.6 and Python 3.4.2
